==> zola-0.16.1.tar.gz: zola-0.16.1/docs/content/themes/d3c3nt/index.md <==

+++
title = "d3c3nt"
description = "A simple, clean, and flexible theme for personal sites."
template = "theme.html"
date = 2022-06-15T01:35:37-07:00

[extra]
created = 2022-06-15T01:35:37-07:00
updated = 2022-06-15T01:35:37-07:00
repository = "git://git.figbert.com/d3c3nt.git"
homepage = "https://git.figbert.com/d3c3nt/"
minimum_version = "0.15.0"
license = "AGPLv3"
demo = "https://d3c3nt.figbert.com"

[extra.author]
name = "FIGBERT"
homepage = "https://figbert.com"
+++        

# d3c3nt

d3c3nt is a simple, clean, and flexible theme for personal sites, made
by [FIGBERT] for the [Zola static site engine][zola]. This theme is
developed mainly for use on my personal site, so new features and styles
will be added when I stumble onto the need to make them.

All in all, it's fairly... decent.

## installation

To use d3c3nt in your own site, you have to add it to your `themes`
directory. You can do this in a variety of ways, but I recommend adding
it as a git submodule:

```
$ cd themes/
$ git submodule add git://git.figbert.com/d3c3nt.git
```

After installing the theme, set the top-level `theme` variable to
`"d3c3nt"` in your `config.toml`.

For more information about Zola themes in general, check out Zola's
[official site][zola-docs]. To find out more about d3c3nt's features and
configuration, head over to the [project's docs][docs].

## whoami

To learn more about me, feel free to check out [my website][FIGBERT] and
subscribe via the [Atom feed][atom]. You can contact me via email at:
[figbert+d3c3nt@figbert.com][email].

[FIGBERT]: https://figbert.com/
[zola]: https://getzola.org/
[zola-docs]: https://www.getzola.org/documentation/themes/overview/
[docs]: https://d3c3nt.figbert.com/config/
[atom]: https://figbert.com/atom.xml
[email]: mailto:figbert+d3c3nt@figbert.com

==> zola-0.17.2.tar.gz: zola-0.17.2/docs/content/themes/d3c3nt/index.md <==

+++
title = "d3c3nt"
description = "A simple, clean, and flexible theme for personal sites."
template = "theme.html"
date = 2022-12-04T21:40:33+02:00

[extra]
created = 2022-12-04T21:40:33+02:00
updated = 2022-12-04T21:40:33+02:00
repository = "git://git.figbert.com/d3c3nt.git"
homepage = "https://git.figbert.com/d3c3nt/"
minimum_version = "0.15.0"
license = "AGPLv3"
demo = "https://d3c3nt.figbert.com"

[extra.author]
name = "FIGBERT"
homepage = "https://figbert.com"
+++        

# d3c3nt

d3c3nt is a simple, clean, and flexible theme for personal sites, made
by [FIGBERT] for the [Zola static site engine][zola]. This theme is
developed mainly for use on my personal site, so new features and styles
will be added when I stumble onto the need to make them.

All in all, it's fairly... decent.

## installation

To use d3c3nt in your own site, you have to add it to your `themes`
directory. You can do this in a variety of ways, but I recommend adding
it as a git submodule:

```
$ cd themes/
$ git submodule add git://git.figbert.com/d3c3nt.git
```

After installing the theme, set the top-level `theme` variable to
`"d3c3nt"` in your `config.toml`.

For more information about Zola themes in general, check out Zola's
[official site][zola-docs]. To find out more about d3c3nt's features and
configuration, head over to the [project's docs][docs].

## whoami

To learn more about me, feel free to check out [my website][FIGBERT] and
subscribe via the [Atom feed][atom]. You can contact me via email at:
[figbert+d3c3nt@figbert.com][email].

[FIGBERT]: https://figbert.com/
[zola]: https://getzola.org/
[zola-docs]: https://www.getzola.org/documentation/themes/overview/
[docs]: https://d3c3nt.figbert.com/config/
[atom]: https://figbert.com/atom.xml
[email]: mailto:figbert+d3c3nt@figbert.com
